EditableMapEffectDB

Struct EditableMapEffectDB 

pub struct EditableMapEffectDB {
    pub effects: BTreeMap<SArc<EffectPath>, BTreeMap<SArc<String>, Value>>,
    pub empty: BTreeMap<SArc<String>, Value>,
}
Editable Effects

A to/from container mirroring [MapEffectsDB], except the inner fields are public. This allows us to edit [MapEffectsDB] in certain contexts where we can fully replace it, without the concern of mutability for contract authors.

Fields

effects: BTreeMap<SArc<EffectPath>, BTreeMap<SArc<String>, Value>>

All Effects currently in the set of effects

empty: BTreeMap<SArc<String>, Value>

Catch-all for extra data for future extension