Module sapio_base::timelocks [−][src]
Helpers for making correct time locks
Modules
| type_tags | Type Tags used for creating lock time variants. The module lets us keep them public while not polluting the name space. |
Structs
| LockTime | LockTime represents either a nLockTime or a Sequence field. They are represented generically in the same type |
Enums
| AnyAbsTimeLock | Represents a type which can be either type of absolute lock |
| AnyRelTimeLock | Represents a type which can be either type of relative lock |
| AnyTimeLock | Represents a type which can be any type of lock |
| LockTimeError |
Type Definitions
| AbsHeight | |
| AbsTime | |
| RelHeight | |
| RelTime |