Type Alias AbsTime
Source pub type AbsTime = LockTime<Abs, MTP>;
LockTime for Absolute MTP
pub struct AbsTime();
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.